﻿using System;
using System.Diagnostics;
using Silanis.ESL.SDK;
using Silanis.ESL.SDK.Builder;
using System.IO;
using System.Collections.Generic;


class CreatingLayouts
{
    // replace the API_KEY placeholder with your api key
    public static String API_KEY = "API_KEY";
    public static String API_URL = "https://sandbox.e-signlive.com/api";

    public static void Main(string[] args) {

		EslClient eslClient = new EslClient(API_KEY, API_URL);
		
		/*-------------------------------------CREATE LAYOUT FROM PACKAGE-------------------------------------*/
		
		// Create your document package
		DocumentPackage myPackage = PackageBuilder.NewPackageNamed("Layout Example NET SDK")
				.DescribedAs("This is a package with document to create layout.")
				.WithSigner(SignerBuilder.NewSignerWithEmail("john.doe@gmail.com")
						.WithCustomId("Signer")
						.WithFirstName("John")
						.WithLastName("Doe")
						.WithTitle("Salesman")
						.WithCompany("BMW"))
				.WithSigner(SignerBuilder.NewSignerWithEmail("mary.doe@gmail.com")
						.WithCustomId("Sender")
						.WithFirstName("Mary")
						.WithLastName("Doe")
						.WithTitle("Senior Manager")
						.WithCompany("Group Insurance Inc."))
				.WithDocument(DocumentBuilder.NewDocumentNamed("My sample document")
						.WithId("documentId")
						.WithDescription("Layout document description")
						.FromFile("DOC_FILE_PATH")
						.EnableExtraction())
				.Build();

		PackageId packageId = eslClient.CreatePackage(myPackage);
		myPackage.Id = packageId;


		// Create layout from package
		String layoutId = eslClient.LayoutService.CreateLayout(myPackage);
		Debug.WriteLine(layoutId);
		
		/*----------------------------------------------------------------------------------------------------*/
		
		/*---------------------------------------RETRIEVE YOUR LAYOUTS----------------------------------------*/

		
		// The first step is to retrieve the layouts from the first page. In my example, I chose to retrieve 5 layouts at a time but you can set this to any number.
        int i = 1;

        IList<DocumentPackage> layouts = eslClient.LayoutService.GetLayouts(Direction.DESCENDING, new PageRequest(i, 5));

        int count = layouts.Count;

        while (count != 0)
        {
            foreach (DocumentPackage j in layouts)
            {
                //This is where you retrieve your layout name and id.
                Debug.WriteLine(j.Name + " " + j.Id);
                i++;
            }
            // Finally, you will retrieve your next 5 layouts from the second page and start over up until you’ve retrieved all your layouts.
            layouts = eslClient.LayoutService.GetLayouts(Direction.DESCENDING, new PageRequest(i, 5));
            count = layouts.Count;
        }
		
		/*-----------------------------------------------------------------------------------------------------*/
		
		/*-----------------------------------------APPLY YOUR LAYOUT-------------------------------------------*/
		
		// Create a new package to apply document layout to
		DocumentPackage packageFromLayout = PackageBuilder.NewPackageNamed("Document Layout Example Java SDK")
				.DescribedAs("This is a package created using the e-SignLive Java SDK")
				.WithSigner(SignerBuilder.NewSignerWithEmail("john.doe@gmail.com")
						.WithCustomId("Signer")
						.WithFirstName("John")
						.WithLastName("Doe")
						.WithTitle("Salesman")
						.WithCompany("BMW"))
				.WithSigner(SignerBuilder.NewSignerWithEmail("mary.doe@gmail.com")
						.WithCustomId("Sender")
						.WithFirstName("Mary")
						.WithLastName("Doe")
						.WithTitle("Senior Manager")
						.WithCompany("Group Insurance Inc."))
				.WithDocument(DocumentBuilder.NewDocumentNamed("Apply Layout Document")
						.WithId("documentId")
						.WithDescription("Document with applied layout description.")
						.FromFile("DOC_FILE_PATH"))
				.Build();

		PackageId packageId2 = eslClient.CreatePackage(packageFromLayout);

		// Apply the layout to document in package
		eslClient.LayoutService.ApplyLayout(packageId2, "documentId", "f682c87b-d806-4120-a29e-0c76aadd9302");
		
		/*-----------------------------------------------------------------------------------------------------*/
	}
}
